@@ -16,9 +16,6 @@ _FP32_OPS: Set[str] = {
     "sin", "cos", "tan",
     # softmax & reductions that accumulate / are variance-based
     "softmax",
-    # norms / stats
-    "batchnorm", "batchnorm2d", "layernorm", "groupnorm", "instancenorm",
-    "var", "variance", "logsumexp",
     "sum", "mean", "std",
     # losses (compute entirely in fp32)
     "mse", "rmse", "mae", "binarycrossentropy", "categoricalcrossentropy",
@@ -71,55 +68,42 @@ def should_cast_to_fp16(op_name: str) -> bool:
     if op_name_lower in _FP16_SAFE_OPS:
         return True
         
-    # Default behavior: keep unknown ops in FP32 for safety
-    return False
+    # Default behavior: allow FP16 for most ops but with caution
+    return True
 
 
-def maybe_cast_data(tensor, target_dtype=None, op_name: str = "unknown"):
+def maybe_cast_tensor(tensor, target_dtype=None, op_name: str = "unknown") -> 'Tensor':
     """
-    Cast underlying array for compute without inserting Cast nodes.
-
-    Returns an xp.ndarray suitable for the op's forward, following autocast policy.
-    This mirrors PyTorch's behavior by selecting compute dtype per-op without
-    modifying the input Tensor's dtype or graph.
+    Cast tensor to appropriate dtype based on autocast context and operation type.
+    
+    Args:
+        tensor: Input tensor
+        target_dtype: Target dtype (if None, uses autocast dtype)
+        op_name: Name of the operation for casting decision
+        
+    Returns:
+        Tensor cast to appropriate dtype
     """
     from neurograd.tensor import Tensor
-
-    # If input isn't a Tensor or autocast disabled, just return raw data
+    
     if not isinstance(tensor, Tensor):
         return tensor
+        
     if not autocast.is_enabled():
-        return tensor.data
-
-    # Avoid recursion/casts for explicit Cast operations
-    if op_name and op_name.lower() == 'cast':
-        return tensor.data
-
-    # Decide target dtype
+        return tensor
+    
+    # Determine target dtype
     if target_dtype is None:
         if should_cast_to_fp16(op_name):
             target_dtype = autocast.get_autocast_dtype()
         else:
-            # Force FP32 for sensitive ops
-            import neurograd as ng
-            target_dtype = ng.float32
-
-    # No-op if already correct dtype
+            return tensor.cast(ng.float32)
+    
+    # Only cast if different from current dtype
     if tensor.data.dtype == target_dtype:
-        return tensor.data
-
-    # Use per-context cache to reuse cast arrays within region
-    cache = autocast.get_cache()
-    if cache is not None:
-        key = ('data', id(tensor), target_dtype)
-        cached = cache.get(key)
-        if cached is not None:
-            return cached
-        arr = tensor.data.astype(target_dtype, copy=False)
-        cache[key] = arr
-        return arr
-
-    return tensor.data.astype(target_dtype, copy=False)
+        return tensor
+        
+    return tensor.cast(target_dtype)
 
 
 def get_fp32_ops() -> Set[str]:
