@@ -3,6 +3,6 @@ from .math import Log, Exp, Sin, Cos, Tan, Sqrt, Cbrt, Log10, Log2, Abs, Clip, l
 from .linalg import MatMul, TensorDot, Transpose, matmul, dot, tensordot, transpose
 from .tensor_ops import Reshape, Flatten, Squeeze, ExpandDims, Pad, SlidingWindowView, \
 reshape, flatten, squeeze, expand_dims, pad, sliding_window_view, newaxis
-from .activations import ReLU, LeakyReLU, Sigmoid, Softmax, Tanh, relu, leaky_relu, sigmoid, softmax, tanh
+from .activations import ReLU, LeakyReLU, ReLU6, Sigmoid, Softmax, Tanh, relu, leaky_relu, relu6, sigmoid, softmax, tanh
 from .base import Function
-from .conv import conv2d, pool2d, maxpool2d, averagepool2d, pooling2d, maxpooling2d, averagepooling2d
\ No newline at end of file
+from .conv import conv2d, pool2d, maxpool2d, averagepool2d, pooling2d, maxpooling2d, averagepooling2d
